@@ -1,13 +1,15 @@
-import threading
 import array
+import threading
+from ctypes import POINTER, Structure, byref, c_long, cast, memmove, pointer, sizeof
 from typing import TYPE_CHECKING
+
 import comtypes
-from ctypes import POINTER, Structure, byref, cast, c_long, memmove, pointer, sizeof
-from comtypes import _safearray, IUnknown, com_interface_registry
+from comtypes import IUnknown, _safearray, com_interface_registry
 from comtypes.patcher import Patch
 
 if TYPE_CHECKING:
-    from typing import Type, TypeVar
+    from typing import TypeVar
+
     from comtypes import hints  # type: ignore
 
     _CT = TypeVar("_CT", bound=comtypes._CData)
@@ -15,7 +17,7 @@ if TYPE_CHECKING:
 _safearray_type_cache = {}
 
 
-class _SafeArrayAsNdArrayContextManager(object):
+class _SafeArrayAsNdArrayContextManager:
     """Context manager allowing safe arrays to be extracted as ndarrays.
 
     This is thread-safe.
@@ -56,7 +58,7 @@ safearray_as_ndarray = _SafeArrayAsNdArrayContextManager()
 
 ################################################################
 # This is THE PUBLIC function: the gateway to the SAFEARRAY functionality.
-def _midlSAFEARRAY(itemtype: "Type[_CT]") -> "Type[hints.LP_SAFEARRAY[_CT]]":
+def _midlSAFEARRAY(itemtype: "type[_CT]") -> "type[hints.LP_SAFEARRAY[_CT]]":
     """This function mimics the 'SAFEARRAY(aType)' IDL idiom.  It
     returns a subtype of SAFEARRAY, instances will be built with a
     typecode VT_...  corresponding to the aType, which must be one of
@@ -73,12 +75,12 @@ def _midlSAFEARRAY(itemtype: "Type[_CT]") -> "Type[hints.LP_SAFEARRAY[_CT]]":
 def _make_safearray_type(itemtype):
     # Create and return a subclass of tagSAFEARRAY
     from comtypes.automation import (
-        _ctype_to_vartype,
+        VT_DISPATCH,
+        VT_HRESULT,
         VT_RECORD,
         VT_UNKNOWN,
         IDispatch,
-        VT_DISPATCH,
-        VT_HRESULT,
+        _ctype_to_vartype,
     )
 
     meta = type(_safearray.tagSAFEARRAY)
@@ -108,7 +110,7 @@ def _make_safearray_type(itemtype):
             raise TypeError(itemtype)
 
     @Patch(POINTER(sa_type))
-    class _(object):
+    class _:
         # Should explain the ideas how SAFEARRAY is used in comtypes
         _itemtype_ = itemtype  # a ctypes type
         _vartype_ = vartype  # a VARTYPE value: VT_...
@@ -376,7 +378,7 @@ def _make_safearray_type(itemtype):
             return tuple(result)  # for compatibility with pywin32.
 
     @Patch(POINTER(POINTER(sa_type)))
-    class __(object):
+    class __:
         @classmethod
         def from_param(cls, value):
             if isinstance(value, cls._type_):
@@ -396,19 +398,19 @@ def _make_safearray_type(itemtype):
 def _ndarray_to_variant_array(value):
     """Convert an ndarray to VARIANT_dtype array"""
     # Check that variant arrays are supported
-    if comtypes.npsupport.interop.VARIANT_dtype is None:
+    if comtypes.npsupport.VARIANT_dtype is None:
         msg = "VARIANT ndarrays require NumPy 1.7 or newer."
         raise RuntimeError(msg)
-    numpy = comtypes.npsupport.interop.numpy
+    numpy = comtypes.npsupport.numpy
 
     # special cases
-    if numpy.issubdtype(value.dtype, comtypes.npsupport.interop.datetime64):
+    if numpy.issubdtype(value.dtype, comtypes.npsupport.datetime64):
         return _datetime64_ndarray_to_variant_array(value)
 
     from comtypes.automation import VARIANT
 
     # Empty array
-    varr = numpy.zeros(value.shape, comtypes.npsupport.interop.VARIANT_dtype, order="F")
+    varr = numpy.zeros(value.shape, comtypes.npsupport.VARIANT_dtype, order="F")
     # Convert each value to a variant and put it in the array.
     varr.flat = [VARIANT(v) for v in value.flat]
     return varr
@@ -421,12 +423,12 @@ def _datetime64_ndarray_to_variant_array(value):
     # fractional days.
     from comtypes.automation import VT_DATE
 
-    numpy = comtypes.npsupport.interop.numpy
+    numpy = comtypes.npsupport.numpy
     value = numpy.array(value, "datetime64[ns]")
-    value = value - comtypes.npsupport.interop.com_null_date64
+    value = value - comtypes.npsupport.com_null_date64
     # Convert to days
     value = value / numpy.timedelta64(1, "D")
-    varr = numpy.zeros(value.shape, comtypes.npsupport.interop.VARIANT_dtype, order="F")
+    varr = numpy.zeros(value.shape, comtypes.npsupport.VARIANT_dtype, order="F")
     varr["vt"] = VT_DATE
     varr["_"]["VT_R8"].flat = value.flat
     return varr
